@@ -21,8 +21,8 @@ from typing import List
 
 from hspylib.core.enums.http_code import HttpCode
 from hspylib.core.tools.commons import sysout
-from hspylib.core.tools.preconditions import check_state, check_not_none, check_argument
-from hspylib.modules.fetch.fetch import put, get
+from hspylib.core.tools.preconditions import check_argument, check_not_none, check_state
+from hspylib.modules.fetch.fetch import get, put
 from requests.exceptions import HTTPError
 
 from firebase.entity.file_entry import FileEntry
@@ -34,6 +34,7 @@ class FileProcessor(ABC):
     @staticmethod
     def upload_files(url: str, file_paths: List[str]) -> int:
         """Upload files to URL"""
+        sysout('Uploading files to Firebase ...')
         file_data = []
         for f_path in file_paths:
             check_state(os.path.exists(f_path), f'Input file "{f_path}" does not exist')
@@ -56,6 +57,7 @@ class FileProcessor(ABC):
         check_argument(
             destination_dir and os.path.exists(destination_dir),
             "Unable find destination directory: {}", destination_dir)
+        sysout(f'Downloading files from Firebase into "{destination_dir}" ...')
         response = get(url)
         check_not_none(response)
         check_not_none(response.body)
@@ -80,7 +82,7 @@ class FileProcessor(ABC):
                 f"{destination_dir}/{os.path.basename(entry['path'])}",
                 entry['data'],
                 entry['size']).save()
-        files = ', \n\t'.join(list(map(lambda e: e['path'], file_entries)))
+        files = ', \n\t'.join(list(map(lambda e: os.path.basename(e['path']), file_entries)))
         sysout(f'%GREEN%File(s) [\n\t{files}\n] successfully downloaded into {destination_dir}%NC%')
 
     @staticmethod
